@@ -30,11 +30,7 @@ CLI_CONFIG = {
         "subcommands": ["state", "exec"],
     },
     "acct_key": {"source": "acct", "os": "ACCT_KEY", "subcommands": ["state", "exec"]},
-    "acct_profile": {
-        "source": "acct",
-        "os": "ACCT_PROFILE",
-        "subcommands": ["state", "exec"],
-    },
+    "acct_profile": {"os": "ACCT_PROFILE", "subcommands": ["state", "exec"],},
 }
 
 CONFIG = {
@@ -67,6 +63,11 @@ CONFIG = {
         "default": [],
         "help": "Arguments to pass to the named execution function",
     },
+    "acct_profile": {
+        "os": "ACCT_PROFILE",
+        "help": "The profile to use when when calling exec modules and states",
+        "default": "default",
+    },
 }
 SUBCOMMANDS = {
     "state": {
