@@ -1,6 +1,9 @@
+__func_alias__ = {"ctx_": "ctx"}
+
+
 def ping(hub):
     return True
 
 
-def ctx(hub, ctx):
+def ctx_(hub, ctx):
     return ctx
