@@ -14,9 +14,8 @@ async def ref(hub, name, sls):
         path = sls.replace(".", "/")
         locs = [f"{path}.sls", f"{path}/init.sls"]
         for loc in locs:
-            full = os.path.join(source, loc)
             cfn = await hub.pop.ref.last(f"idem.sls.{proto}.cache")(
-                hub.idem.RUNS[name]["cache_dir"], full
+                hub.idem.RUNS[name]["cache_dir"], source, loc
             )
             if cfn:
                 return cfn
