@@ -76,27 +76,28 @@ async def cli_sls(hub):
     Execute the cli routine to run states
     """
     src = hub.idem.init.get_refs()
+    name = "cli"
     await hub.idem.state.apply(
-        "cli",
-        src["sls_sources"],
-        hub.OPT["idem"]["render"],
-        hub.OPT["idem"]["runtime"],
-        ["states"],
-        hub.OPT["idem"]["cache_dir"],
-        src["sls"],
-        hub.OPT["idem"]["test"],
-        hub.OPT["acct"]["acct_file"],
-        hub.OPT["acct"]["acct_key"],
-        hub.OPT["acct"]["acct_profile"],
+        name=name,
+        sls_sources=src["sls_sources"],
+        render=hub.OPT.idem.render,
+        runtime=hub.OPT.idem.runtime,
+        subs=["states"],
+        cache_dir=hub.OPT.idem.cache_dir,
+        sls=src["sls"],
+        test=hub.OPT.idem.test,
+        acct_file=hub.OPT.acct.acct_file,
+        acct_key=hub.OPT.acct.acct_key,
+        acct_profile=hub.OPT.idem.acct_profile,
     )
 
-    errors = hub.idem.RUNS["cli"]["errors"]
+    errors = hub.idem.RUNS[name]["errors"]
     if errors:
         display = getattr(hub, "output.nested.display")(errors)
         print(display)
         return
-    running = hub.idem.RUNS["cli"]["running"]
-    output = hub.OPT["idem"]["output"]
+    running = hub.idem.RUNS[name]["running"]
+    output = hub.OPT.idem.output
     display = getattr(hub, f"output.{output}.display")(running)
     print(display)
 
@@ -113,18 +114,14 @@ async def cli_exec(hub):
             kwargs.update(arg)
         else:
             args.append(arg)
-    try:
-        ret = await hub.idem.ex.run(
-            exec_path,
-            args,
-            kwargs,
-            hub.OPT.acct.acct_file,
-            hub.OPT.acct.acct_key,
-            hub.OPT.acct.acct_profile,
-        )
-    except AttributeError:
-        print(f"The desired execution is not available: {exec_path}")
-        return
+    ret = await hub.idem.ex.run(
+        exec_path,
+        args,
+        kwargs,
+        hub.OPT.acct.acct_file,
+        hub.OPT.acct.acct_key,
+        hub.OPT.idem.acct_profile,
+    )
     output = hub.OPT.idem.output
     # exec can't use the idem outputter
     # TODO in pop-config allow subcommands to have different defaults from their parent
